@@ -1556,9 +1556,9 @@ def schedules_get(context, id_, team_name):
         The json output from the API on success, None otherwise
 
     """
-    if not all([id_, team_name]):
+    if not any([id_, team_name]):
         raise click.UsageError(
-            "No schedule id or team name was specified. Use --id or --team_name.\n"
+            "No schedule id or team name was specified. Use --id or --team-name.\n"
         )
     if id_:
         result = context.obj['opsgenie'].get_schedules_by_id(id_)
